import * as ai from 'ai';
import { LanguageModelV1, CoreTool as CoreTool$1, CoreMessage, UserContent } from 'ai';
import { ZodSchema, z } from 'zod';
import { Query } from 'sift';

declare const RegisteredLogger: {
    readonly AGENT: "AGENT";
    readonly WORKFLOW: "WORKFLOW";
};
type RegisteredLogger = (typeof RegisteredLogger)[keyof typeof RegisteredLogger];
declare const LogLevel: {
    readonly DEBUG: "DEBUG";
    readonly INFO: "INFO";
    readonly WARN: "WARN";
    readonly ERROR: "ERROR";
};
type LogLevel = (typeof LogLevel)[keyof typeof LogLevel];
interface BaseLogMessage {
    message: string;
    destinationPath: string;
    type: RegisteredLogger;
}
interface Logger<T extends BaseLogMessage = BaseLogMessage> {
    debug(message: T | string, ...args: any[]): void | Promise<void>;
    info(message: T | string, ...args: any[]): void | Promise<void>;
    warn(message: T | string, ...args: any[]): void | Promise<void>;
    error(message: T | string, ...args: any[]): void | Promise<void>;
    cleanup?(): Promise<void>;
}
type LoggerConfig = {
    type: 'CONSOLE';
    level?: LogLevel;
} | {
    type: 'FILE';
    level?: LogLevel;
    dirPath?: string;
} | {
    type: 'UPSTASH';
    level?: LogLevel;
    url: string;
    token: string;
    key?: string;
};
declare abstract class BaseLogger<T extends BaseLogMessage = BaseLogMessage> implements Logger<T> {
    protected level: LogLevel;
    constructor(level?: LogLevel);
    abstract log(level: LogLevel, message: T | string, ...args: any[]): void | Promise<void>;
    debug(message: T | string, ...args: any[]): void | Promise<void>;
    info(message: T | string, ...args: any[]): void | Promise<void>;
    warn(message: T | string, ...args: any[]): void | Promise<void>;
    error(message: T | string, ...args: any[]): void | Promise<void>;
    protected formatMessage(message: T | string): string;
    protected formatLogEntry(level: LogLevel, message: T | string): any;
}
declare class MultiLogger<T extends BaseLogMessage = BaseLogMessage> implements Logger<T> {
    private loggers;
    constructor(loggers: Logger<T>[]);
    debug(message: T | string, ...args: any[]): Promise<void>;
    info(message: T | string, ...args: any[]): Promise<void>;
    warn(message: T | string, ...args: any[]): Promise<void>;
    error(message: T | string, ...args: any[]): Promise<void>;
    cleanup(): Promise<void>;
}
declare function createLogger<T extends BaseLogMessage = BaseLogMessage>(config: LoggerConfig): Logger<T>;
declare function createMultiLogger<T extends BaseLogMessage = BaseLogMessage>(loggers: Logger<T>[]): Logger<T>;

type OpenAIModel = 'gpt-4' | 'gpt-4-turbo' | 'gpt-3.5-turbo' | 'gpt-4o' | 'gpt-4o-mini';
type OpenAIConfig = {
    provider: 'OPEN_AI';
    name: OpenAIModel | (string & {});
    toolChoice: 'auto' | 'required';
    apiKey?: string;
};
type GoogleModel = 'gemini-1.5-pro-latest' | 'gemini-1.5-pro' | 'gemini-1.5-flash-latest' | 'gemini-1.5-flash';
type GoogleConfig = {
    provider: 'GOOGLE';
    name: GoogleModel | (string & {});
    toolChoice: 'auto' | 'required';
    apiKey?: string;
};
interface GoogleGenerativeAISettings {
    /**
    Optional.
    The name of the cached content used as context to serve the prediction.
    Format: cachedContents/{cachedContent}
       */
    cachedContent?: string;
    /**
     * Optional. Enable structured output. Default is true.
     *
     * This is useful when the JSON Schema contains elements that are
     * not supported by the OpenAPI schema version that
     * Google Generative AI uses. You can use this to disable
     * structured outputs if you need to.
     */
    structuredOutputs?: boolean;
    /**
    Optional. A list of unique safety settings for blocking unsafe content.
       */
    safetySettings?: Array<{
        category: 'HARM_CATEGORY_HATE_SPEECH' | 'HARM_CATEGORY_DANGEROUS_CONTENT' | 'HARM_CATEGORY_HARASSMENT' | 'HARM_CATEGORY_SEXUALLY_EXPLICIT';
        threshold: 'HARM_BLOCK_THRESHOLD_UNSPECIFIED' | 'BLOCK_LOW_AND_ABOVE' | 'BLOCK_MEDIUM_AND_ABOVE' | 'BLOCK_ONLY_HIGH' | 'BLOCK_NONE';
    }>;
}
type AnthropicModel = 'claude-3-5-sonnet-20241022' | 'claude-3-5-sonnet-20240620' | 'claude-3-5-haiku-20241022' | 'claude-3-opus-20240229' | 'claude-3-sonnet-20240229' | 'claude-3-haiku-20240307';
type AnthropicConfig = {
    provider: 'ANTHROPIC';
    name: AnthropicModel | (string & {});
    toolChoice: 'auto' | 'required';
    apiKey?: string;
};
type GroqModel = 'llama3-groq-70b-8192-tool-use-preview' | 'llama3-groq-8b-8192-tool-use-preview' | 'gemma2-9b-it' | 'gemma-7b-it';
type GroqConfig = {
    provider: 'GROQ';
    name: GroqModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type PerplexityModel = 'llama-3.1-sonar-small-128k-online' | 'llama-3.1-sonar-large-128k-online' | 'llama-3.1-sonar-huge-128k-online' | 'llama-3.1-sonar-small-128k-chat' | 'llama-3.1-sonar-large-128k-chat' | 'llama-3.1-8b-instruct' | 'llama-3.1-70b-instruct';
type PerplexityConfig = {
    provider: 'PERPLEXITY';
    name: PerplexityModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type TogetherAiModel = 'codellama/CodeLlama-34b-Instruct-hf' | 'upstage/SOLAR-10.7B-Instruct-v1.0' | 'mistralai/Mixtral-8x7B-v0.1' | 'WhereIsAI/UAE-Large-V1' | 'black-forest-labs/FLUX.1-depth' | 'togethercomputer/m2-bert-80M-32k-retrieval' | 'black-forest-labs/FLUX.1-canny' | 'black-forest-labs/FLUX.1-dev' | 'black-forest-labs/FLUX.1-redux' | 'BAAI/bge-large-en-v1.5' | 'meta-llama/Llama-3.2-90B-Vision-Instruct-Turbo' | 'togethercomputer/Llama-3-8b-chat-hf-int4' | 'stabilityai/stable-diffusion-xl-base-1.0' | 'Gryphe/MythoMax-L2-13b' | 'meta-llama/Meta-Llama-3-8B' | 'mistralai/Mixtral-8x7B-Instruct-v0.1' | 'deepseek-ai/deepseek-llm-67b-chat' | 'togethercomputer/m2-bert-80M-8k-retrieval' | 'llava-hf/llava-v1.6-mistral-7b-hf' | 'Qwen/Qwen2.5-Coder-32B-Instruct' | 'databricks/dbrx-instruct' | 'meta-llama/Meta-Llama-3.1-405B-Instruct-Lite-Pro' | 'meta-llama/Meta-Llama-3-8B-Instruct-Lite' | 'scb10x/scb10x-llama3-typhoon-v1-5-8b-instruct' | 'microsoft/WizardLM-2-8x22B' | 'BAAI/bge-base-en-v1.5' | 'togethercomputer/m2-bert-80M-2k-retrieval' | 'google/gemma-2b-it' | 'meta-llama/Llama-2-70b-hf' | 'mistralai/Mistral-7B-Instruct-v0.2' | 'meta-llama/LlamaGuard-2-8b' | 'mistralai/Mistral-7B-Instruct-v0.1' | 'mistralai/Mistral-7B-v0.1' | 'black-forest-labs/FLUX.1-pro' | 'black-forest-labs/FLUX.1-schnell' | 'meta-llama/Meta-Llama-3.1-405B-Instruct-Turbo' | 'nvidia/Llama-3.1-Nemotron-70B-Instruct-HF' | 'mistralai/Mistral-7B-Instruct-v0.3' | 'Meta-Llama/Llama-Guard-7b' | 'meta-llama/Meta-Llama-3-70B-Instruct-Turbo' | 'meta-llama/Meta-Llama-3-70B-Instruct-Lite' | 'google/gemma-2-27b-it' | 'meta-llama/Llama-3-8b-chat-hf' | 'Qwen/Qwen2.5-72B-Instruct-Turbo' | 'Salesforce/Llama-Rank-V1' | 'meta-llama/Llama-Guard-3-11B-Vision-Turbo' | 'google/gemma-2-9b-it' | 'meta-llama/Llama-3.2-11B-Vision-Instruct-Turbo' | 'NousResearch/Nous-Hermes-2-Mixtral-8x7B-DPO' | 'meta-llama/Llama-3-70b-chat-hf' | 'Qwen/Qwen2.5-7B-Instruct-Turbo' | 'scb10x/scb10x-llama3-typhoon-v1-5x-4f316' | 'meta-llama/Meta-Llama-3.1-8B-Instruct-Turbo' | 'Gryphe/MythoMax-L2-13b-Lite' | 'black-forest-labs/FLUX.1-schnell-Free' | 'meta-llama/Llama-2-7b-chat-hf' | 'meta-llama/Meta-Llama-Guard-3-8B' | 'togethercomputer/Llama-3-8b-chat-hf-int8' | 'meta-llama/Llama-Vision-Free' | 'Qwen/Qwen2-72B-Instruct' | 'mistralai/Mixtral-8x22B-Instruct-v0.1' | 'black-forest-labs/FLUX.1.1-pro' | 'meta-llama/Llama-3.2-3B-Instruct-Turbo' | 'meta-llama/Llama-2-13b-chat-hf' | 'meta-llama/Meta-Llama-3.1-70B-Instruct-Turbo' | 'Nexusflow/NexusRaven-V2-13B' | 'bert-base-uncased' | 'WizardLM/WizardLM-13B-V1.2' | 'google/gemma-7b' | 'togethercomputer/Koala-7B' | 'zero-one-ai/Yi-34B' | 'togethercomputer/StripedHyena-Hessian-7B' | 'teknium/OpenHermes-2-Mistral-7B' | 'Qwen/Qwen2-7B-Instruct' | 'togethercomputer/guanaco-65b' | 'togethercomputer/llama-2-7b' | 'hazyresearch/M2-BERT-2k-Retrieval-Encoder-V1' | 'huggyllama/llama-7b' | 'Undi95/ReMM-SLERP-L2-13B' | 'NousResearch/Nous-Capybara-7B-V1p9' | 'lmsys/vicuna-7b-v1.3' | 'Undi95/Toppy-M-7B' | 'Qwen/Qwen2-72B' | 'NousResearch/Nous-Hermes-Llama2-70b' | 'WizardLM/WizardLM-70B-V1.0' | 'huggyllama/llama-65b' | 'lmsys/vicuna-13b-v1.5-16k' | 'openchat/openchat-3.5-1210' | 'Qwen/Qwen1.5-0.5B' | 'Qwen/Qwen1.5-4B' | 'Qwen/Qwen1.5-7B' | 'snorkelai/Snorkel-Mistral-PairRM-DPO' | 'Qwen/Qwen1.5-14B-Chat' | 'Qwen/Qwen1.5-1.8B-Chat' | 'Snowflake/snowflake-arctic-instruct' | 'togethercomputer/llama-2-13b' | 'NousResearch/Nous-Hermes-2-Mixtral-8x7B-SFT' | 'deepseek-ai/deepseek-coder-33b-instruct' | 'togethercomputer/CodeLlama-7b-Instruct' | 'NousResearch/Nous-Hermes-Llama2-13b' | 'lmsys/vicuna-13b-v1.5' | 'togethercomputer/guanaco-13b' | 'togethercomputer/CodeLlama-34b-Instruct' | 'togethercomputer/llama-2-70b' | 'codellama/CodeLlama-13b-Instruct-hf' | 'Qwen/Qwen2-7B' | 'Qwen/Qwen2-1.5B' | 'togethercomputer/CodeLlama-13b-Instruct' | 'meta-llama/Llama-2-13b-hf' | 'togethercomputer/llama-2-13b-chat' | 'huggyllama/llama-30b' | 'NousResearch/Nous-Hermes-2-Mistral-7B-DPO' | 'togethercomputer/alpaca-7b' | 'google/gemma-7b-it' | 'allenai/OLMo-7B' | 'togethercomputer/guanaco-33b' | 'togethercomputer/llama-2-7b-chat' | 'togethercomputer/SOLAR-10.7B-Instruct-v1.0-int4' | 'togethercomputer/guanaco-7b' | 'Open-Orca/Mistral-7B-OpenOrca' | 'Qwen/Qwen1.5-32B' | 'EleutherAI/llemma_7b' | 'NousResearch/Nous-Hermes-llama-2-7b' | 'Qwen/Qwen1.5-32B-Chat' | 'meta-llama/Meta-Llama-3-70B' | 'meta-llama/Llama-3-8b-hf' | 'sentence-transformers/msmarco-bert-base-dot-v5' | 'zero-one-ai/Yi-6B' | 'meta-llama/Meta-Llama-3-8B-Instruct' | 'teknium/OpenHermes-2p5-Mistral-7B' | 'Qwen/Qwen1.5-4B-Chat' | 'wavymulder/Analog-Diffusion' | 'runwayml/stable-diffusion-v1-5' | 'prompthero/openjourney' | 'meta-llama/Llama-2-7b-hf' | 'SG161222/Realistic_Vision_V3.0_VAE' | 'Qwen/Qwen1.5-0.5B-Chat' | 'codellama/CodeLlama-7b-Instruct-hf' | 'google/gemma-2b' | 'mistralai/Mixtral-8x22B' | 'meta-llama/Llama-2-70b-chat-hf' | 'zero-one-ai/Yi-34B-Chat' | 'google/gemma-2-9b' | 'meta-llama/Meta-Llama-3-70B-Instruct' | 'togethercomputer/LLaMA-2-7B-32K' | 'codellama/CodeLlama-70b-Instruct-hf' | 'NousResearch/Hermes-2-Theta-Llama-3-70B' | 'test/test11' | 'stabilityai/stable-diffusion-2-1' | 'microsoft/phi-2' | 'Qwen/Qwen1.5-7B-Chat' | 'cognitivecomputations/dolphin-2.5-mixtral-8x7b' | 'togethercomputer/evo-1-131k-base' | 'togethercomputer/evo-1-8k-base' | 'togethercomputer/llama-2-70b-chat' | 'Qwen/Qwen1.5-14B' | 'carson/ml318br' | 'meta-llama/Meta-Llama-3.1-8B-Instruct-Reference' | 'meta-llama/Meta-Llama-3.1-8B-Reference' | 'gradientai/Llama-3-70B-Instruct-Gradient-1048k' | 'meta-llama/Meta-Llama-3.1-70B-Reference' | 'meta-llama/Meta-Llama-3.1-70B-Instruct-Reference' | 'meta-llama/Llama-3-70b-hf' | 'Qwen/Qwen2-1.5B-Instruct' | 'NousResearch/Nous-Hermes-13b' | 'HuggingFaceH4/zephyr-7b-beta' | 'Austism/chronos-hermes-13b' | 'Qwen/Qwen1.5-1.8B' | 'Qwen/Qwen1.5-72B' | 'lmsys/vicuna-13b-v1.3' | 'huggyllama/llama-13b' | 'garage-bAInd/Platypus2-70B-instruct' | 'allenai/OLMo-7B-Instruct' | 'togethercomputer/Koala-13B' | 'lmsys/vicuna-7b-v1.5';
type TogetherAiConfig = {
    provider: 'TOGETHER_AI';
    name: TogetherAiModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type LMStudioModel = 'qwen2-7b-instruct-4bit' | 'qwen2-math-1.5b' | 'qwen2-0.5b' | 'aya-23-8b' | 'mistral-7b-v0.3' | 'stablecode' | 'cohere-command-r-v01-4bit' | 'command-r' | 'starcoder2-7b' | 'deepseek-math-7b' | 'qwen2.5-coder-14b' | 'qwen2.5-coder-32b' | 'qwen2.5-coder-3b' | 'llama-3.2-3b-instruct-4bit' | 'llama-3.2-1b' | 'llama-3.2-3b' | 'qwen2.5-coder-7b' | 'qwen2.5-14b' | 'yi-coder-9b' | 'hermes-3-llama-3.1-8b' | 'internlm-2.5-20b' | 'llava-v1.5' | 'llama-3.1-8b-instruct-4bit' | 'meta-llama-3.1-8b' | 'mistral-nemo-2407' | 'mistral-nemo-instruct-2407-4bit' | 'gemma-2-2b' | 'mathstral-7b' | 'gemma-2-9b' | 'deepseek-coder-v2-lite-instruct-4bit' | 'smollm-360m-v0.2' | 'phi-3-mini-4k-instruct-4bit' | 'gemma-2-27b' | 'codestral-22b' | 'phi-3.1-mini-128k' | 'deepseek-coder-v2-lite';
type LMStudioConfig = {
    provider: 'LM_STUDIO';
    name: LMStudioModel | (string & {});
    toolChoice: 'auto' | 'required';
    baseURL: string;
};
type BasetenModel = 'llama-3.1-70b-instruct' | 'qwen2.5-7b-math-instruct' | 'qwen2.5-14b-instruct' | 'qwen2.5-32b-coder-instruct' | 'llama-3.1-8b-instruct' | 'llama-3.1-nemetron-70b' | 'llama-3.2-90b-vision-instruct' | 'llama-3.1-405b-instruct' | 'ultravox-v0.4' | 'llama-3.2-1b-vision-instruct' | 'llama-3-70b-instruct' | 'llama-3-8b-instruct' | 'mistral-7b-instruct' | 'qwen2.5-14b-coder-instruct' | 'qwen2.5-7b-coder-instruct' | 'qwen2.5-72b-math-instruct' | 'qwen2.5-72b-instruct' | 'qwen2.5-32b-instruct' | 'qwen2.5-7b-instruct' | 'qwen2.5-3b-instruct' | 'pixtral-12b' | 'phi-3.5-mini-instruct' | 'gemma-2-9b' | 'gemma-2-27b' | 'phi-3-mini-128k-instruct' | 'phi-3-mini-4k-instruct' | 'zephyr-7b-alpha' | 'mixtral-8x7b-instruct' | 'mixtral-8x22b';
type BaseTenConfig = {
    provider: 'BASETEN';
    name: BasetenModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
    fetch?: typeof globalThis.fetch;
};
type FireworksModel = 'llama-3.1-405b-instruct' | 'llama-3.1-70b-instruct' | 'llama-3.1-8b-instruct' | 'llama-3.2-3b-instruct';
type FireworksConfig = {
    provider: 'FIREWORKS';
    name: FireworksModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type MistralModel = 'pixtral-large-latest' | 'mistral-large-latest' | 'mistral-small-latest' | 'ministral-3b-latest' | 'ministral-8b-latest' | 'pixtral-12b-2409';
type MistralConfig = {
    provider: 'MISTRAL';
    name: MistralModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type XGrokModel = 'grok-beta' | 'grok-vision-beta';
type XGrokConfig = {
    provider: 'X_GROK';
    name: XGrokModel | (string & {});
    toolChoice: 'auto' | 'required';
    apiKey?: string;
};
type CustomModelConfig = {
    model: LanguageModelV1 | (() => Promise<LanguageModelV1>);
    provider: string;
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type CohereModel = 'command-r-plus';
type CohereConfig = {
    provider: 'COHERE';
    name: CohereModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type AzureModel = 'gpt-35-turbo-instruct';
type AzureConfig = {
    provider: 'AZURE';
    name: AzureModel & (string | {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type AmazonModel = 'amazon-titan-tg1-large' | 'amazon-titan-text-express-v1' | 'anthropic-claude-3-5-sonnet-20241022-v2:0' | 'anthropic-claude-3-5-sonnet-20240620-v1:0' | 'anthropic-claude-3-5-haiku-20241022-v1:0' | 'anthropic-claude-3-opus-20240229-v1:0' | 'anthropic-claude-3-sonnet-20240229-v1:0' | 'anthropic-claude-3-haiku-20240307-v1:0' | 'anthropic-claude-v2:1' | 'cohere-command-r-v1:0' | 'cohere-command-r-plus-v1:0' | 'meta-llama2-13b-chat-v1' | 'meta-llama2-70b-chat-v1' | 'meta-llama3-8b-instruct-v1:0' | 'meta-llama3-70b-instruct-v1:0' | 'meta-llama3-1-8b-instruct-v1:0' | 'meta-llama3-1-70b-instruct-v1:0' | 'meta-llama3-1-405b-instruct-v1:0' | 'meta-llama3-2-1b-instruct-v1:0' | 'meta-llama3-2-3b-instruct-v1:0' | 'meta-llama3-2-11b-instruct-v1:0' | 'meta-llama3-2-90b-instruct-v1:0' | 'mistral-mistral-7b-instruct-v0:2' | 'mistral-mixtral-8x7b-instruct-v0:1' | 'mistral-mistral-large-2402-v1:0' | 'mistral-mistral-small-2402-v1:0';
type AmazonConfig = {
    provider: 'AMAZON';
    name: AmazonModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type AnthropicVertexModel = 'claude-3-5-sonnet@20240620' | 'claude-3-opus@20240229' | 'claude-3-sonnet@20240229' | 'claude-3-haiku@20240307';
type AnthropicVertexConfig = {
    provider: 'ANTHROPIC_VERTEX';
    name: AnthropicVertexModel | (string & {});
    apiKey?: string;
    toolChoice: 'auto' | 'required';
};
type BuiltInModelConfig = OpenAIConfig | AnthropicConfig | GroqConfig | GoogleConfig | PerplexityConfig | TogetherAiConfig | LMStudioConfig | BaseTenConfig | FireworksConfig | MistralConfig | XGrokConfig | CohereConfig | AzureConfig | AmazonConfig | AnthropicVertexConfig;
type ModelConfig = BuiltInModelConfig | CustomModelConfig;
type LLMProvider = BuiltInModelConfig['provider'];

declare class LLM<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    #private;
    logger: Logger;
    constructor(logger?: Logger);
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    getModelType(model: ModelConfig): string;
    createOpenAICompatibleModel({ baseURL, apiKey, defaultModelName, modelName, fetch, }: {
        baseURL: string;
        apiKey: string;
        defaultModelName: string;
        modelName?: string;
        fetch?: typeof globalThis.fetch;
    }): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            fetch?: typeof globalThis.fetch;
            apiKey?: string;
        };
    }): LanguageModelV1;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: ({
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            apiKey?: string;
            fetch?: typeof globalThis.fetch;
        } & GoogleGenerativeAISettings) | CustomModelConfig;
    }): Promise<{
        toolsConverted: Record<string, CoreTool$1>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    }>;
    convertTools(enabledTools?: Partial<Record<TKeys, boolean>>): Record<TKeys, CoreTool>;
    text({ model, messages, onStepFinish, maxSteps, enabledTools, }: {
        enabledTools?: Partial<Record<TKeys, boolean>>;
        model: ModelConfig;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<ai.GenerateTextResult<{}>>;
    stream({ model, messages, onStepFinish, onFinish, maxSteps, enabledTools, }: {
        model: ModelConfig;
        enabledTools: Partial<Record<TKeys, boolean>>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    }): Promise<ai.StreamTextResult<{}>>;
}

type ValueOf<T> = Required<T>[keyof T];
declare const filterQuerySchema: z.ZodObject<Record<ValueOf<typeof FilterOperators>, any>, "strip", z.ZodTypeAny, {
    is?: any;
    eq?: any;
    not_eq?: any;
    contains?: any;
    in?: any;
    not_in?: any;
    gt?: any;
    lt?: any;
    not_contains?: any;
    gte?: any;
    lte?: any;
    op?: any;
    set?: any;
    not_set?: any;
}, {
    is?: any;
    eq?: any;
    not_eq?: any;
    contains?: any;
    in?: any;
    not_in?: any;
    gt?: any;
    lt?: any;
    not_contains?: any;
    gte?: any;
    lte?: any;
    op?: any;
    set?: any;
    not_set?: any;
}>;
declare const sortQuerySchema: z.ZodEffects<z.ZodString, string[] | undefined, string>;

interface BaseConnection {
    id: string;
    name: string;
    issues: string[];
    syncConfig: Record<string, any> | null;
    connectionId: string;
    createdAt: Date;
    updatedAt: Date | null;
    lastSyncAt: Date | null;
    subscriptionId?: string | null;
    error?: string | null;
}
interface BaseCredential {
    id: string;
    type: string;
    value: Record<string, any>;
    scope: string[];
    kId: string | null;
}
type CredentialInput = Omit<BaseCredential, "id" | "kId">;
type CredentialWithConnection = {
    id: string;
    type: string;
    value: Record<string, any>;
    scope: string[];
    kId: string | null;
    connection: BaseConnection | null;
};
interface BaseEntity {
    id: string;
    kId: string | null;
    type: string;
    lastSyncId: string | null;
    createdBy: string;
    createdAt: Date;
    updatedAt: Date | null;
}
type CredentialUpdateInput = Partial<{
    type: string;
    value: Record<string, any>;
    scope: string[];
}>;
interface BaseRecord {
    id: string;
    entityId: string;
    data: Record<string, any>;
    createdAt: Date;
    updatedAt: Date | null;
    externalId: string | null;
    entityType: string;
}
interface BaseProperty {
    id?: string;
    name: string;
    displayName: string;
    visible: boolean;
    config: Record<string, any>;
    description: string | null;
    type: PropertyType;
    order: number;
    modifiable: boolean;
    entityId?: string;
}
declare enum PropertyType {
    'LONG_TEXT' = "LONG_TEXT",
    'SINGLE_LINE_TEXT' = "SINGLE_LINE_TEXT",
    'SINGLE_SELECT' = "SINGLE_SELECT",
    'MULTI_SELECT' = "MULTI_SELECT",
    'CHECKBOX' = "CHECKBOX",
    'DATE' = "DATE",
    'USER' = "USER",
    'BADGE_LIST' = "BADGE_LIST",
    'CURRENCY' = "CURRENCY",
    'URL' = "URL",
    'PHONE' = "PHONE",
    'CONTACT' = "CONTACT",
    'COMPANY' = "COMPANY",
    'PERSON' = "PERSON",
    'ENRICHMENT' = "ENRICHMENT",
    'COMPOSITE' = "COMPOSITE",
    'BOOLEAN' = "BOOLEAN",
    'NUMBER' = "NUMBER",
    'FLOAT' = "FLOAT",
    'JSON_OBJECT' = "JSON_OBJECT",
    'JSON_ARRAY' = "JSON_ARRAY"
}
type FilterObject<T extends string | number | symbol> = Record<T, z.infer<typeof filterQuerySchema>>;
interface FilterClauseArgs<T extends string | number | symbol> {
    parentTableRef?: string;
    filters: FilterObject<T>;
    fields?: Pick<BaseProperty, 'name' | 'type'>[];
}
interface SortClauseArgs {
    parentTableRef?: string;
    sort: string[];
    fields?: Pick<BaseProperty, 'name' | 'type'>[];
}
declare enum FilterOperators {
    IS = "is",
    EQUAL = "eq",
    NOT_EQUAL = "not_eq",
    CONTAINS = "contains",
    IN = "in",
    NOT_IN = "not_in",
    GREATER_THAN = "gt",
    LESS_THAN = "lt",
    NOT_CONTAINS = "not_contains",
    GREATER_THAN_OR_EQUAL = "gte",
    LESS_THAN_OR_EQUAL = "lte",
    OP = "op",
    SET = "set",
    NOT_SET = "not_set"
}

declare const FieldTypePrimitiveMap: Record<PropertyType, string>;
/**
 * Split a string on commas and strip quotes from each part
 * @param str input string
 * @returns array of strings
 */
declare const splitAndStripQuotes: (str: string) => string[];
declare const transformFilterValueArray: (value: string | undefined) => string[] | undefined;
declare const transformFilterValueBoolean: (value: string | undefined) => boolean | undefined;
/**
 * This returns the SQL field for a JSON field with appropriate casting.
 * @param column - JSON field to cast.
 * @param type - Type of the JSON field.
 */
declare const getJSONField: (column: string, type: PropertyType) => string;
/**
 * @description
 * Builds a query string from filter and sort query strings
 * @param filterQueryString Filter query string
 * @param sortQueryString Sort query string
 * @returns
 */
declare function buildQueryString({ filterQueryString, sortQueryString, }: {
    filterQueryString?: string;
    sortQueryString?: string;
}): string;

interface DatabaseConfig {
    url: string;
}
declare abstract class MastraEngine {
    /**
     * Initializes the database connection
     * @param config Configuration object for database connection
     */
    constructor(config: DatabaseConfig);
    /**
     * Closes the database connection
     */
    abstract close(): Promise<void>;
    abstract getConnection(params: {
        name: string;
        connectionId: string;
    }): Promise<BaseConnection>;
    abstract getConnectionById(params: {
        kId: string;
    }): Promise<BaseConnection | undefined>;
    abstract getAllConnections(): Promise<Pick<BaseConnection, 'name' | 'connectionId'>[]>;
    abstract getConnectionsByIntegrationName(params: {
        name: string;
    }): Promise<BaseConnection[]>;
    abstract getConnectionsBySubscriptionId(params: {
        subscriptionId: string;
    }): Promise<BaseConnection[]>;
    abstract setConnectionSubscriptionId(params: {
        kId: string;
        subscriptionId: string;
    }): Promise<BaseConnection>;
    abstract createConnection(params: {
        connection: Omit<BaseConnection, 'createdAt' | 'updatedAt' | 'id' | 'lastSyncAt'>;
        credential: CredentialInput;
    }): Promise<BaseConnection & {
        credential: BaseCredential;
    }>;
    abstract setConnectionError(params: {
        kId: string;
        error: string;
    }): Promise<BaseConnection>;
    abstract deleteConnection(params: {
        kId: string;
    }): Promise<BaseConnection | null>;
    abstract getCredentialsByConnection(kId: string): Promise<CredentialWithConnection>;
    abstract updateConnectionCredentialToken(params: {
        kId: string;
        token: Record<string, any>;
    }): Promise<BaseCredential>;
    abstract updateConnectionCredentials(params: CredentialUpdateInput & {
        kId: string;
    }): Promise<BaseCredential>;
    abstract createEntity(params: {
        kId: string;
        type: string;
        connectionId: string;
    }): Promise<BaseEntity>;
    abstract getEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    abstract getEntityByConnectionAndType(params: {
        kId: string;
        type: string;
    }): Promise<BaseEntity | null>;
    abstract getEntityRecordsByConnectionAndType(params: {
        kId: string;
        type: string;
    }): Promise<BaseEntity & {
        properties: BaseProperty[];
        records: BaseRecord[];
    } | null>;
    abstract updateEntityLastSyncId(params: {
        id: string;
        syncId: string;
    }): Promise<BaseEntity>;
    abstract deleteEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    abstract mergeExternalRecordsForEntity(params: {
        entityId: string;
        records: Pick<BaseRecord, 'externalId' | 'data' | 'entityType'>[];
    }): Promise<void>;
    abstract getRecordsByPropertyName(params: {
        propertyName: string;
        connectionId: string;
    }): Promise<{
        record: BaseRecord;
    }[]>;
    abstract getRecordByPropertyNameAndValue(params: {
        propertyName: string;
        propertyValue: string;
        type: string;
        connectionId: string;
    }): Promise<BaseRecord | null>;
    abstract getRecordByPropertyNameAndValues(params: {
        propertyName: string;
        propertyValues: string[];
        type?: string;
        connectionId: string;
    }): Promise<{
        record: BaseRecord;
    }[]>;
    abstract deleteRecordsByEntityId(params: {
        id: string;
    }): Promise<BaseRecord[]>;
    abstract addPropertiesToEntity(params: {
        entityId: string;
        properties: BaseProperty[];
    }): Promise<BaseEntity>;
    abstract getPropertiesByEntityType(params: {
        entityType: string;
    }): Promise<BaseProperty[]>;
    abstract deletePropertiesByEntityId(params: {
        id: string;
    }): Promise<BaseProperty[]>;
    abstract syncData(params: {
        connectionId: string;
        name: string;
        data: any;
        type: string;
        properties: BaseProperty[];
        lastSyncId?: string;
    }): Promise<void>;
    abstract buildRecordQuerySql(params: {
        whereClause: string;
        filterClause?: string;
        entityType: string;
        sortClauses: string[];
    }): string;
    abstract getFilteredRecords<T extends string | number | symbol>(params: {
        entityType: string;
        filters?: FilterObject<T>;
        sort?: string[];
        kId: string;
    }): Promise<any[]>;
    abstract getRecords<T extends string | number | symbol>(params: {
        entityType: string;
        kId: string;
        filters?: FilterObject<T>;
        sort?: string[];
    }): Promise<any[]>;
}

type CoreTool = {
    description: string;
    parameters: ZodSchema;
    execute: (params: any) => Promise<any>;
};
interface IntegrationApiExcutorParams<T extends Record<string, unknown>> {
    data: T;
    getIntegration: <I extends Integration[]>(name: I[number]['name']) => Extract<I[number], {
        name: I[number]['name'];
    }>;
    llm: LLM<Integration[], any, any>;
    engine?: MastraEngine | undefined;
    agents: Map<string, Agent<Integration[], any>>;
}
type ToolApi<IN extends Record<string, unknown> = Record<string, unknown>, OUT extends Record<string, unknown> = Record<string, unknown>> = {
    schema: ZodSchema<IN>;
    label: string;
    description: string;
    documentation?: string;
    executor: (params: IntegrationApiExcutorParams<IN>) => Promise<OUT>;
};
type IntegrationTools<T extends Integration> = T['tools'];
type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
type MergeIntegrationTools<T extends Integration[]> = UnionToIntersection<IntegrationTools<T[number]>>;
type AllTools<TTools, TIntegrations extends Integration[] | undefined = undefined> = TTools & (TIntegrations extends Integration[] ? MergeIntegrationTools<TIntegrations> : {});

declare abstract class Integration {
    abstract readonly name: string;
    abstract readonly logoUrl: string;
    abstract readonly tools: Record<string, ToolApi>;
    authType: string;
    constructor();
    protected get toolSchemas(): any;
    protected get toolDocumentations(): Record<string, {
        comment: string;
        doc?: string;
    }>;
    protected get baseClient(): any;
    getApiClient(): Promise<any>;
    protected _generateIntegrationTools<T>(): T;
}

declare class Agent<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    name: string;
    readonly llm: LLM<TTools, TIntegrations, TKeys>;
    readonly instructions: string;
    readonly model: ModelConfig;
    readonly enabledTools: Partial<Record<TKeys, boolean>>;
    logger: Logger;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
    });
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    text({ messages, onStepFinish, maxSteps, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    }): Promise<ai.GenerateTextResult<{}>>;
    stream({ messages, onStepFinish, onFinish, maxSteps, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    }): Promise<ai.StreamTextResult<{}>>;
}

declare function createTool<IN extends Record<string, any> = Record<string, any>, OUT extends Record<string, any> = Record<string, any>>(opts: ToolApi<IN, OUT>): ToolApi<IN, OUT>;

interface QueryResult {
    id: string;
    score: number;
    metadata?: Record<string, any>;
}
interface IndexStats {
    dimension: number;
    count: number;
    metric?: 'cosine' | 'euclidean' | 'dotproduct';
}
declare abstract class MastraVector {
    abstract upsert(indexName: string, vectors: number[][], metadata?: Record<string, any>[], ids?: string[]): Promise<string[]>;
    abstract createIndex(indexName: string, dimension: number, metric?: 'cosine' | 'euclidean' | 'dotproduct'): Promise<void>;
    abstract query(indexName: string, queryVector: number[], topK?: number, filter?: Record<string, any>): Promise<QueryResult[]>;
    abstract listIndexes(): Promise<string[]>;
    abstract describeIndex(indexName: string): Promise<IndexStats>;
    abstract deleteIndex(indexName: string): Promise<void>;
}

type SyncConfig<TIntegrations extends Integration[], MastraTools, TParams> = (params: {
    tools: AllTools<MastraTools, TIntegrations>;
    params: TParams;
    engine: MastraEngine;
    vectors?: Record<string, MastraVector>;
    agents: Map<string, Agent<MastraTools, TIntegrations>>;
    llm: LLM<MastraTools, TIntegrations, keyof AllTools<MastraTools, TIntegrations>>;
}) => Promise<void>;
interface SyncMap {
    [key: string]: SyncConfig<Integration[], Record<string, ToolApi>, any>;
}

declare const StepIdBrand: unique symbol;
type StepId = string & {
    readonly [StepIdBrand]: typeof StepIdBrand;
};
type StepResult<T> = T extends (data: any) => Promise<infer R> ? R : never;
interface VariableReference<TStepId extends string = string, TPath extends string = string> {
    stepId: TStepId | 'trigger';
    path: TPath;
}
interface BaseCondition<T = any> {
    ref: {
        stepId: string | 'trigger';
        path: string;
    };
    query: Query<T>;
}
type StepCondition<T = any> = BaseCondition<T> | {
    and: StepCondition<T>[];
} | {
    or: StepCondition<T>[];
};
interface StepTransition<T = any> {
    condition?: StepCondition<T>;
}
interface StepConfig<TInput = any, TOutput = any, TTransitions extends string = string> {
    id: StepId;
    handler: (data: TInput) => Promise<TOutput>;
    inputSchema?: z.ZodType<TInput>;
    requiredData: Record<string, VariableReference>;
    transitions?: Record<TTransitions, StepTransition> | null;
}
interface StepDefinition<TSchema extends z.ZodType<any>, TOutput = any, TTransitions extends string = string> {
    action: (data: z.infer<TSchema>) => Promise<TOutput>;
    inputSchema?: TSchema;
    variables?: Partial<Record<keyof z.infer<TSchema>, VariableReference>>;
    payload?: Partial<z.infer<TSchema>>;
    transitions?: Record<TTransitions, StepTransition> | null;
}
interface WorkflowContext<TTrigger = any, TStepResults = any> {
    error: Error | null;
    stepResults: Record<string, TStepResults>;
    triggerData: TTrigger;
}
interface WorkflowLogMessage extends BaseLogMessage {
    type: typeof RegisteredLogger.WORKFLOW;
    workflowName: string;
    stepId?: StepId;
    data?: unknown;
}
type ValidationErrorType = 'circular_dependency' | 'no_terminal_path' | 'unreachable_step';
interface ValidationError {
    type: ValidationErrorType;
    message: string;
    details: {
        stepId?: StepId;
        path?: StepId[];
    };
}
interface WorkflowDefinition<TTrigger = any, TSteps extends Record<string, StepDefinition<any, any>> = Record<string, StepDefinition<any, any>>> {
    name: string;
    triggerSchema?: z.ZodType<TTrigger>;
    steps: TSteps;
}
type WorkflowEvent = {
    type: `TRANSITION_${string}`;
    output?: unknown;
} | {
    type: 'NO_MATCHING_CONDITIONS';
} | {
    type: `xstate.error.actor.${string}`;
    error: Error;
} | {
    type: `xstate.done.actor.${string}`;
    output: ResolverFunctionOutput;
};
type ResolverFunctionInput = {
    step: StepConfig;
    context: WorkflowContext;
};
type ResolverFunctionOutput = {
    stepId: StepId;
    result: unknown;
};
type WorkflowActors = {
    resolverFunction: {
        input: ResolverFunctionInput;
        output: ResolverFunctionOutput;
    };
};
type WorkflowActions = {
    type: 'updateStepResult' | 'setError' | 'initializeTriggerData';
    params?: unknown;
};
type WorkflowState = {
    [key: string]: {
        invoke?: {
            src: 'resolverFunction';
            input: ({ context, }: {
                context: WorkflowContext;
            }) => ResolverFunctionInput;
            onDone: {
                actions: ['updateStepResult'];
                target?: string;
            };
            onError: {
                target: 'failure';
                actions: ['setError'];
            };
        };
        on: {
            NO_MATCHING_CONDITIONS: {
                target: 'failure';
                actions: any;
            };
            [key: `TRANSITION_${string}`]: {
                target: string;
                guard: ({ context }: {
                    context: WorkflowContext;
                }) => boolean;
            };
        };
    };
};

declare class Workflow<TTrigger = any, TSteps extends Record<string, StepDefinition<any, any>> = Record<string, StepDefinition<any, any>>> {
    #private;
    name: string;
    triggerSchema?: z.ZodType<any>;
    /**
     * Creates a new Workflow instance
     * @param name - Identifier for the workflow (not necessarily unique)
     * @param logger - Optional logger instance
     */
    constructor(name: string, logger?: Logger<WorkflowLogMessage>);
    /**
     * Initializes the XState machine for the workflow
     *
     * Registers the machine's types, actions, actors, initial context, entry actions, initial state, and states
     * @returns The initialized machine
     */
    private initializeMachine;
    /**
     * Rebuilds the machine with the current steps configuration and validates the workflow
     *
     * This is the last step of a workflow builder method chain
     * @throws Error if validation fails
     */
    commit(): void;
    /**
     * Sets the schema for validating trigger data
     * @param schema - Zod schema for trigger data validation
     * @returns this instance for method chaining
     */
    setTriggerSchema(schema: z.ZodType<any>): this;
    /**
     * Adds a new step to the workflow
     * @param id - Unique identifier for the step
     * @param config - Step configuration including handler, schema, variables, and payload
     * @returns this instance for method chaining (builder pattern baybyyyy)
     * @throws Error if step ID is duplicate or variable resolution fails
     */
    addStep<TSchema extends z.ZodType<any>, TOutput = any, TTransitions extends string = string>(id: string, config: StepDefinition<TSchema, TOutput, TTransitions>): Workflow<TTrigger, TSteps & Record<typeof id, typeof config>>;
    /**
     * Executes the workflow with the given trigger data
     * @param triggerData - Initial data to start the workflow with
     * @returns Promise resolving to workflow results or rejecting with error
     * @throws Error if trigger schema validation fails
     */
    executeWorkflow<TSchema = unknown, TTrigger = this['triggerSchema'] extends z.ZodSchema<infer T> ? T : TSchema>(triggerData?: TTrigger): Promise<{
        triggerData?: TTrigger;
        results: Record<string, unknown>;
    }>;
}

declare class Mastra<TIntegrations extends Integration[], MastraTools extends Record<string, any>, TSyncs extends Record<string, SyncConfig<TIntegrations, MastraTools, any>> = Record<never, never>> {
    private engine?;
    private vectors?;
    private tools;
    private agents;
    llm: LLM<MastraTools, TIntegrations, keyof AllTools<MastraTools, TIntegrations>>;
    private integrations;
    private logger;
    private syncs;
    private workflows;
    constructor(config: {
        tools?: MastraTools;
        syncs?: TSyncs;
        agents?: Agent<MastraTools, TIntegrations>[];
        integrations?: TIntegrations;
        engine?: MastraEngine;
        vectors?: Record<string, MastraVector>;
        logger?: Logger;
        workflows?: Workflow[];
    });
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K] extends SyncConfig<any, any, infer P> ? P : never): Promise<void>;
    getAgent(name: string): Agent<MastraTools, TIntegrations, keyof MastraTools | keyof (TIntegrations extends Integration[] ? (IntegrationTools<TIntegrations[number]> extends infer T ? T extends IntegrationTools<TIntegrations[number]> ? T extends any ? (k: T) => void : never : never : never) extends (k: infer I) => void ? I : never : {})>;
    getIntegration<I extends TIntegrations[number]['name']>(name: I): Extract<TIntegrations[number], {
        name: I;
    }>;
    getTool<T extends keyof MastraTools>(name: T): AllTools<MastraTools, TIntegrations>[T] & {
        execute: (params: z.infer<MastraTools[T]["schema"]>) => Promise<any>;
    };
    availableIntegrations(): {
        name: string;
        integration: Integration;
    }[];
    getTools(): AllTools<MastraTools, TIntegrations>;
    setLogger({ key, logger }: {
        key: RegisteredLogger;
        logger: Logger;
    }): void;
    getLogger(key: RegisteredLogger): Logger<BaseLogMessage> | undefined;
}

export { Agent, AllTools, AmazonConfig, AmazonModel, AnthropicConfig, AnthropicModel, AnthropicVertexConfig, AnthropicVertexModel, AzureConfig, AzureModel, BaseCondition, BaseConnection, BaseCredential, BaseEntity, BaseLogMessage, BaseLogger, BaseProperty, BaseRecord, BaseTenConfig, BasetenModel, CohereConfig, CohereModel, CoreTool, CredentialInput, CredentialUpdateInput, CredentialWithConnection, CustomModelConfig, DatabaseConfig, FieldTypePrimitiveMap, FilterClauseArgs, FilterObject, FilterOperators, FireworksConfig, FireworksModel, GoogleConfig, GoogleGenerativeAISettings, GoogleModel, GroqConfig, GroqModel, IndexStats, Integration, IntegrationApiExcutorParams, IntegrationTools, LLMProvider, LMStudioConfig, LMStudioModel, LogLevel, Logger, LoggerConfig, Mastra, MastraEngine, MastraVector, MergeIntegrationTools, MistralConfig, MistralModel, ModelConfig, MultiLogger, OpenAIConfig, OpenAIModel, PerplexityConfig, PerplexityModel, PropertyType, QueryResult, RegisteredLogger, ResolverFunctionInput, ResolverFunctionOutput, SortClauseArgs, StepCondition, StepConfig, StepDefinition, StepId, StepResult, StepTransition, SyncConfig, SyncMap, TogetherAiConfig, TogetherAiModel, ToolApi, ValidationError, ValidationErrorType, VariableReference, Workflow, WorkflowActions, WorkflowActors, WorkflowContext, WorkflowDefinition, WorkflowEvent, WorkflowLogMessage, WorkflowState, XGrokConfig, XGrokModel, buildQueryString, createLogger, createMultiLogger, createTool, filterQuerySchema, getJSONField, sortQuerySchema, splitAndStripQuotes, transformFilterValueArray, transformFilterValueBoolean };
